pub struct AttributeProto {Show 14 fields
pub name: String,
pub ref_attr_name: String,
pub doc_string: String,
pub type: i32,
pub f: f32,
pub i: i64,
pub s: Vec<u8>,
pub t: Option<TensorProto>,
pub g: Option<GraphProto>,
pub floats: Vec<f32>,
pub ints: Vec<i64>,
pub strings: Vec<Vec<u8>>,
pub tensors: Vec<TensorProto>,
pub graphs: Vec<GraphProto>,
}Expand description
Attribute on a NodeProto.
Fields
name: Stringref_attr_name: Stringdoc_string: Stringtype: i32f: f32Single-valued attributes (one-of-discriminated by type).
i: i64s: Vec<u8>t: Option<TensorProto>g: Option<GraphProto>floats: Vec<f32>List-valued attributes.
ints: Vec<i64>strings: Vec<Vec<u8>>tensors: Vec<TensorProto>graphs: Vec<GraphProto>Implementations
Sourceimpl AttributeProto
impl AttributeProto
Sourcepub fn type(&self) -> AttributeType
pub fn type(&self) -> AttributeType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: AttributeType)
pub fn set_type(&mut self, value: AttributeType)
Sets type to the provided enum value.